<?php

namespace app\admin\controller\I18n\I18nLangType;

use app\BaseController;
use app\common\model\I18n\I18nLangType\I18nLangType as ModelI18nLangType;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use app\common\exception\Tool;
use think\facade\Db;
use think\facade\Env;


class I18nLangType extends BaseController
{
    /**
     * 获取多语言类型列表
     */
    public function getI18nLangTypeList(Request $request, $isExport = false): array
    {
        $params = $request->param();
        $con = [];

        $con = Tool::getOptionalQuery(['i18n_lang_type_name', 'LIKE'],['i18n_lang_type_code', 'LIKE']);

        $query = ModelI18nLangType::where($con)
            ->field([
                'i18n_lang_type_id',
                'i18n_lang_type_guid',
                'i18n_lang_type_name',
                'i18n_lang_type_code',
                'i18n_lang_type_sort'
            ])
            ->order('i18n_lang_type_sort', 'asc');

        return $isExport ?  $query->select()->toArray() : msg("获取多语言类型列表成功!", $query);
    }

    /**
     * 添加多语言类型
     */
    public function addI18nLangType(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'i18n_lang_type_name|名称' => 'require',
            'i18n_lang_type_code|code码' => 'require',
            // 'i18n_lang_type_sort|排序' => 'require'
        ]);
        $model = ModelI18nLangType::create($params, [
            'i18n_lang_type_name',
            'i18n_lang_type_code',
            'i18n_lang_type_sort',
            'i18n_lang_type_guid',
            'i18n_lang_type_create_user_guid',
            'i18n_lang_type_update_user_guid'
        ]);
        return msg('添加成功!');
    }

    /**
     * 编辑多语言类型
     */
    public function editI18nLangType(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'i18n_lang_type_name|名称' => 'require',
            'i18n_lang_type_code|code码' => 'require',
            // 'i18n_lang_type_sort|排序' => 'require'
        ]);
        $model = ModelI18nLangType::where('i18n_lang_type_guid', $params['i18n_lang_type_guid'])->find();
        if (!$model) throwErrorMsg("该多语言类型不存在", 1);
        $model->allowField([
            'i18n_lang_type_name',
            'i18n_lang_type_code',
            'i18n_lang_type_sort',
            'i18n_lang_type_update_user_guid'
        ])->save($params);
        return msg('编辑成功!');
    }

    /**
     * 删除多语言类型
     */
    public function deleteI18nLangType(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'i18n_lang_type_guid' => 'require',
        ]);
        $i18n_lang_type = ModelI18nLangType::where([
            'i18n_lang_type_guid' => explode(',', $params['i18n_lang_type_guid'])
        ])->select();
        $i18n_lang_type->delete();
        return msg('删除成功!');
    }
}
