<?php

namespace app\admin\controller\LeaveMessage;

use app\BaseController;
use app\common\model\LeaveMessage\LeaveMessage as ModelLeaveMessage;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use app\common\exception\Tool;
use think\facade\Db;
use think\facade\Env;


class LeaveMessage extends BaseController
{
    /**
     * 获取留言列表
     */
    public function getLeaveMessageList(Request $request, $isExport = false): array
    {
        $params = $request->param();
        $con = [];

        $con = Tool::getOptionalQuery(['leave_message_name', 'LIKE'], ['leave_message_phone', 'LIKE'], ['leave_message_email', 'LIKE'],);

        $query = ModelLeaveMessage::where($con)
            ->field([
                'leave_message_id',
                'leave_message_guid',
                'leave_message_name',
                'leave_message_phone',
                'leave_message_email',
                'leave_message_info'
            ])
            ->order('leave_message_create_time', 'desc');

        return $isExport ?  $query->select()->toArray() : msg("获取留言列表成功!", $query);
    }

    /**
     * 添加留言
     */
    public function addLeaveMessage(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'leave_message_name|姓名' => 'require',
            'leave_message_phone|电话' => 'require',
            'leave_message_email|邮箱' => 'require',
            'leave_message_info|信息' => 'require'
        ]);
        $model = ModelLeaveMessage::create($params, [
            'leave_message_name',
            'leave_message_phone',
            'leave_message_email',
            'leave_message_info',
            'leave_message_guid',
            'leave_message_create_user_guid',
            'leave_message_update_user_guid'
        ]);
        return msg('添加成功!');
    }

    /**
     * 编辑留言
     */
    public function editLeaveMessage(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'leave_message_name|姓名' => 'require',
            'leave_message_phone|电话' => 'require',
            'leave_message_email|邮箱' => 'require',
            'leave_message_info|信息' => 'require'
        ]);
        $model = ModelLeaveMessage::where('leave_message_guid', $params['leave_message_guid'])->find();
        if (!$model) throwErrorMsg("该留言不存在", 1);
        $model->allowField([
            'leave_message_name',
            'leave_message_phone',
            'leave_message_email',
            'leave_message_info',
            'leave_message_update_user_guid'
        ])->save($params);
        return msg('编辑成功!');
    }

    /**
     * 删除留言
     */
    public function deleteLeaveMessage(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'leave_message_id' => 'require',
        ]);
        $leave_message = ModelLeaveMessage::where([
            'leave_message_id' => explode(',', $params['leave_message_id'])
        ])->select();
        $leave_message->delete();
        return msg('删除成功!');
    }

    /**
     * 导出Excel
     */
    public function exportExcel(Request $request): void
    {
        ModelLeaveMessage::exportExcel(self::getLeaveMessageList($request, true));
    }
}
