<?php

namespace app\admin\controller\News;

use app\BaseController;
use app\common\model\News\News as ModelNews;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use app\common\exception\Tool;
use think\facade\Db;
use think\facade\Env;


class News extends BaseController
{
    /**
     * 获取新闻列表
     */
    public function getNewsList(Request $request, $isExport = false): array
    {
        $params = $request->param();
        $con = [];

        $con = Tool::getOptionalQuery(['news_type', '='], ['news_title', 'LIKE'], ['c.i18n_lang_type_guid', '=']);

        $query = ModelNews::where($con)
            ->alias('a')
            ->leftjoin('i18n_lang_type c', 'a.i18n_lang_type_guid = c.i18n_lang_type_guid')
            ->field([
                'news_id',
                'news_guid',
                'news_type',
                'news_cover',
                'news_title',
                'news_intro',
                'news_source',
                'news_link',
                'news_issue_date',
                'news_views_num',
                'news_sort',
                'news_content',
                'a.i18n_lang_type_guid',
                'c.i18n_lang_type_name',
                'c.i18n_lang_type_code',
            ])
            ->order('news_sort', 'asc');

        return $isExport ?  $query->select()->toArray() : msg("获取新闻列表成功!", $query);
    }

    /**
     * 添加新闻
     */
    public function addNews(Request $request): array
    {
        Db::startTrans();
        Tool::adminLockTableWrite('news');
        try {
            $params = $request->param();
            $this->validate($params, [
                'news_type|新闻类型' => 'require',
                'news_title|新闻标题' => 'require',
                'news_cover|新闻封面' => 'require',
                'news_sort|新闻排序' => 'require'
            ]);
            $model = ModelNews::create($params, [
                'i18n_lang_type_guid',
                'news_type',
                'news_title',
                'news_cover',
                'news_intro',
                'news_source',
                'news_link',
                'news_issue_date',
                'news_views_num',
                'news_sort',
                'news_content',
                'news_guid',
                'news_create_user_guid',
                'news_update_user_guid'
            ]);
            Db::commit();
            Tool::unlockTable();
            return msg('添加成功!');
        } catch (\Throwable $th) {
            Db::rollback();
            Tool::unlockTable();
            throw  $th;
        }
    }

    /**
     * 编辑新闻
     */
    public function editNews(Request $request): array
    {
        Db::startTrans();
        Tool::adminLockTableWrite('news');
        try {
            $params = $request->param();
            $this->validate($params, [
                'news_type|新闻类型' => 'require',
                'news_title|新闻标题' => 'require',
                'news_cover|新闻封面' => 'require',
                'news_sort|新闻排序' => 'require'
            ]);
            $model = ModelNews::where('news_guid', $params['news_guid'])->find();
            if (!$model) throwErrorMsg("该新闻不存在", 1);
            $model->allowField([
                'i18n_lang_type_guid',
                'news_type',
                'news_title',
                'news_cover',
                'news_intro',
                'news_source',
                'news_link',
                'news_issue_date',
                'news_views_num',
                'news_sort',
                'news_content',
                'news_update_user_guid'
            ])->save($params);
            Db::commit();
            Tool::unlockTable();
            return msg('编辑成功!');
        } catch (\Throwable $th) {
            Db::rollback();
            Tool::unlockTable();
            throw  $th;
        }
    }

    /**
     * 删除新闻
     */
    public function deleteNews(Request $request): array
    {
        Db::startTrans();
        Tool::adminLockTableWrite('news');
        try {
            $params = $request->param();
            $this->validate($params, [
                'news_guid' => 'require',
            ]);
            $news = ModelNews::where([
                'news_guid' => explode(',', $params['news_guid'])
            ])->select();
            $news->delete();
            Db::commit();
            Tool::unlockTable();
            return msg('删除成功!');
        } catch (\Throwable $th) {
            Db::rollback();
            Tool::unlockTable();
            throw  $th;
        }
    }

    /**
     * 导出Excel
     */
    public function exportExcel(Request $request): void
    {
        ModelNews::exportExcel(self::getNewsList($request, true));
    }

    /**
     * 下载导入模板
     */
    public function downloadTemplate(Request $request): void
    {
        $params = $request->param();
        $data = [
            array_values(ModelNews::EXCELFIELD),
            [
                'zh',
                '公司新闻',
                '机床的先进数控：领先的软件',
                '/uploads/NewsImg/20240401\fcb291d25ebd321a4dcb864cdc308454.jpg',
                '我们的先进数控机床技术为提升生产效率提供了独特优势。我们提供的领先软件确保了机床的可靠和精确控制，这有助于减少设置时间并确保加工零件的高精度。',
                '广东隆邦智能装备实业有限公司',
                '',
                '2023.6.9',
                '0',
                '1',
                '<p>我们的先进数控机床技术为提升生产效率提供了独特优势。我们提供的领先软件确保了机床的可靠和精确控制，这有助于减少设置时间并确保加工零件的高精度。</p><p>先进数控机床的优势</p><p>我们的先进数控机床技术提供了高速加工和最小化错误概率。这显著提高了生产效率和经济效益。可靠的控制系统确保了机床即使在长时间运行下也能稳定工作。</p><p>灵活的加工参数设置功能使机床能够适应各种任务和生产要求。这有助于提高生产质量，并在更换任务时节省机床重新设置的时间。我们的先进数控机床技术在零件加工中提供了速度和精度的最佳组合。</p><p>我们的先进数控机床技术使用起来简单方便。直观的界面使操作员能够快速掌握软件并有效地使用其所有功能。这有助于减少人员培训时间并提高劳动生产率。</p><p>领先的软件，实现高效工作</p><p>我们的领先软件提供了对加工过程的全面控制，并能够快速响应生产环境的变化。监控和控制系统允许远程控制机床并实时跟踪其工作状态。</p><p>与其他生产自动化系统的集成优化了机床和其他设备之间的交互。这降低了错误风险并提高了整个生产过程的有效性。我们的领先软件不仅确保了机床的最佳运行，还改善了整个生产线的互动。</p><p>由于我们先进数控机床技术的定期更新和支持，您将始终领先于竞争对手一步。我们不断努力改进我们的软件，为您提供最先进的技术和工具来管理机床。</p><p>选择我们的先进数控机床技术和领先软件，您将获得优化生产过程和提高企业效率的可靠伙伴。我们专业的团队随时准备支持您并帮助解决任何问题。不要落后于竞争对手 - 选择我们产品的质量和可靠性！</p><p><br></p>',
            ]
        ];
        $excel = (new Excel())->exporTsheet($data);
        $excel->save('新闻导入模板.xlsx');
    }

    /**
     * 导入excel
     */
    public function importExcel(Request $request): array
    {
        $file = new UploadFile('uploads', 'fileExt:xlsx');
        $file->putFile('news');
        $msg = ModelNews::importExcel($file);
        return [
            'code' => 0,
            'msg' => $msg
        ];
    }
}
