<?php

namespace app\admin\controller\Products;

use app\BaseController;
use app\common\model\Products\ProductTypeLang as ModelProductTypeLang;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use app\common\exception\Tool;
use think\facade\Db;
use think\facade\Env;


class ProductTypeLang extends BaseController
{
    /**
     * 获取产品类型多语言列表
     */
    public function getProductTypeLangList(Request $request, $isExport = false): array
    {
        $params = $request->param();
        $con = [];

        $con = Tool::getOptionalQuery(['a.product_type_guid', '='], ['a.i18n_lang_type_guid', '='], ['product_type_lang_name', 'LIKE'],);

        $query = ModelProductTypeLang::where($con)
            ->alias('a')
            ->leftjoin('product_type b', 'a.product_type_guid = b.product_type_guid')
            ->leftjoin('i18n_lang_type c', 'a.i18n_lang_type_guid = c.i18n_lang_type_guid')
            ->field([
                'a.product_type_lang_id',
                'b.product_type_name',
                'c.i18n_lang_type_code',
                'a.product_type_lang_guid',
                'a.product_type_guid',
                'a.i18n_lang_type_guid',
                'a.product_type_lang_name'
            ])
            ->order('product_type_lang_create_time', 'desc');

        return $isExport ?  $query->select()->toArray() : msg("获取产品类型多语言列表成功!", $query);
    }

    /**
     * 添加产品类型多语言
     */
    public function addProductTypeLang(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'product_type_guid|产品类型guid' => 'require',
            'i18n_lang_type_guid|语言类型guid' => 'require',
            'product_type_lang_name|产品类型多语言名称' => 'require'
        ]);
        $model = ModelProductTypeLang::create($params, [
            'product_type_guid',
            'i18n_lang_type_guid',
            'product_type_lang_name',
            'product_type_lang_guid',
            'product_type_lang_create_user_guid',
            'product_type_lang_update_user_guid'
        ]);
        return msg('添加成功!');
    }

    /**
     * 编辑产品类型多语言
     */
    public function editProductTypeLang(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'product_type_guid|产品类型guid' => 'require',
            'i18n_lang_type_guid|语言类型guid' => 'require',
            'product_type_lang_name|产品类型多语言名称' => 'require'
        ]);
        $model = ModelProductTypeLang::where('product_type_lang_guid', $params['product_type_lang_guid'])->find();
        if (!$model) throwErrorMsg("该产品类型多语言不存在", 1);
        $model->allowField([
            'product_type_guid',
            'i18n_lang_type_guid',
            'product_type_lang_name',
            'product_type_lang_update_user_guid'
        ])->save($params);
        return msg('编辑成功!');
    }

    /**
     * 删除产品类型多语言
     */
    public function deleteProductTypeLang(Request $request): array
    {
        $params = $request->param();
        $this->validate($params, [
            'product_type_lang_guid' => 'require',
        ]);
        $product_type_lang = ModelProductTypeLang::where([
            'product_type_lang_guid' => explode(',', $params['product_type_lang_guid'])
        ])->select();
        $product_type_lang->delete();
        return msg('删除成功!');
    }

    /**
     * 导出Excel
     */
    public function exportExcel(Request $request): void
    {
        ModelProductTypeLang::exportExcel(self::getProductTypeLangList($request, true));
    }

    /**
     * 下载导入模板
     */
    public function downloadTemplate(Request $request): void
    {
        $params = $request->param();
        $data = [
            array_values(ModelProductTypeLang::EXCELFIELD),
            ['en', 'DSL & FD 系列', 'DSL & FD Service',]
        ];
        $excel = (new Excel())->exporTsheet($data);
        $excel->save('产品类型多语言导入模板.xlsx');
    }

    /**
     * 导入excel
     */
    public function importExcel(Request $request): array
    {
        $file = new UploadFile('uploads', 'fileExt:xlsx');
        $file->putFile('product_type_lang');
        $msg = ModelProductTypeLang::importExcel($file);
        return [
            'code' => 0,
            'msg' => $msg
        ];
    }
}
