<?php

namespace app\api\controller\Products;

use app\BaseController;
use app\common\model\Products\Product as ModelProduct;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use think\facade\Db;
use app\common\exception\Tool;
use think\facade\Env;


class Product extends BaseController
{
    /**
     * 获取产品列表
     */
    public function getProductList(Request $request): array
    {
        $params = $request->param();
        $con = [];

        $this->validate($params, ['locale' => 'require']);
        $con = Tool::getOptionalQuery(['b.product_type_id', '='], ['c.i18n_lang_type_code', '=', 'locale'], ['product_name', 'LIKE'],);

        $locale = $params['locale'];

        $query = ModelProduct::where($con)
            ->alias('a')
            ->leftjoin('product_type b', 'a.product_type_guid = b.product_type_guid')
            ->leftjoin('i18n_lang_type c', 'a.i18n_lang_type_guid = c.i18n_lang_type_guid')
            ->field([
                'a.product_id',
                'a.product_guid',
                'a.product_type_guid',
                'c.i18n_lang_type_code',
                'b.product_type_id',
                'a.product_name',
                'a.product_img',
                'a.product_description',
                'a.product_link',
                'a.product_sort'
            ])
            ->order('product_sort', 'asc');
        // ->select();

        return msg("获取产品列表成功!", $query);

        // return msg(0, "获取产品列表成功!", [
        //     'data' => $query,
        //     'count' => count($query)
        // ]);
    }


    /**
     * 获取热门产品列表
     */
    public function getHotProductList(Request $request): array
    {
        $params = $request->param();
        $con = [];

        $this->validate($params, ['locale' => 'require']);
        $con = Tool::getOptionalQuery(['c.i18n_lang_type_code', '=', 'locale']);

        $query = ModelProduct::where($con)
            ->alias('a')
            ->leftjoin('product_type b', 'a.product_type_guid = b.product_type_guid')
            ->leftjoin('i18n_lang_type c', 'a.i18n_lang_type_guid = c.i18n_lang_type_guid')
            ->where('a.product_is_hot', 1)
            ->field([
                'a.product_id',
                'a.product_guid',
                'a.product_type_guid',
                'c.i18n_lang_type_code',
                'b.product_type_id',
                'a.product_name',
                'a.product_img',
                'a.product_description',
                'a.product_link',
                'a.product_sort'
            ])
            ->order('product_sort', 'asc');
        // ->select();

        return msg("获取产品列表成功!", $query);

        // return msg(0, "获取产品列表成功!", [
        //     'data' => $query,
        //     'count' => count($query)
        // ]);
    }


    /**
     * 获取产品详情
     */
    public function getProductInfo(Request $request): array
    {
        $params = $request->param();

        $this->validate($params, ['product_id' => 'require', 'locale' => 'require']);

        $find = ModelProduct::field([
            'product_id',
            'product_guid',
            'product_type_guid',
            'product_name',
            'product_img',
            'product_description',
            'product_link',
            'product_details',
            'product_sort'
        ])
            ->where('product_id', $params['product_id'])
            ->find();

        return msg(0, '获取产品详情成功!', ['data' => $find]);
    }
}
