<?php

namespace app\common\model\Faq;

use app\common\arw\adjfut\src\Validate;
use app\BaseModel;
use think\model\concern\SoftDelete;
use app\common\arw\adjfut\src\Excel;
use app\Request;
use app\common\exception\Tool;
use app\common\model\I18n\I18nLangType\I18nLangType as ModelI18nLangType;
use think\facade\Db;

class Faq extends BaseModel
{
    use SoftDelete;
    // 删除字段
    protected $deleteTime = 'faq_delete_time';
    // 设置主键名
    protected $pk = 'faq_guid';
    // 设置废弃字段
    protected $disuse = [];
    // 设置字段信息
    protected $schema = [
        'faq_id' => 'int',
        'faq_guid' => 'string',
        'i18n_lang_type_guid' => 'string',
        'faq_questions' => 'string',
        'faq_answer' => 'string',
        'faq_sort' => 'int',
        'faq_create_time' => 'datetime',
        'faq_create_user_guid' => 'string',
        'faq_update_time' => 'datetime',
        'faq_update_user_guid' => 'string',
        'faq_delete_time' => 'datetime',
        'faq_delete_user_guid' => 'string',

    ];
    // 设置json类型字段
    protected $json = [''];
    // 开启自动写入时间戳字段
    protected $autoWriteTimestamp = 'datetime';
    // 创建时间
    protected $createTime = 'faq_create_time';
    // 修改时间
    protected $updateTime = 'faq_update_time';

    //排序字段
    public $order_field = 'faq_sort';

    // excel导入/下载模板表头
    public const EXCELFIELD = [
        'i18n_lang_type_code' => '语言类型code码',
        'faq_questions' => '问题',
        'faq_answer' => '答案',
        'faq_sort' => '顺序',
    ];

    /**
     * 新增前
     */
    public static function onBeforeInsert(self $model): void
    {
        Tool::dataAddSortProc($model);
        $model->completeCreateField();
    }

    /**
     * 更新前
     */
    public static function onBeforeUpdate(self $model): void
    {
        Tool::dataEditSortProc($model);
        $model->completeUpdateField();
    }

    /**
     * 删除前
     */
    public static function onBeforeDelete(self $model): void
    {
        Tool::dataDeleteSortProc($model);
        $model->completeDeleteField();
    }


    /**
     * 导出Excel
     * 
     * @param array $select 导出的数据
     */
    public static function exportExcel(array $select): void
    {
        $data = [[
            '语言类型code码',
            '问题',
            '答案',
            '顺序'
        ]];
        foreach ($select as $key => $val) {
            $i18n_lang_type = ModelI18nLangType::where('i18n_lang_type_guid', $val['$i18n_lang_type_guid'])->find();
            if (!$i18n_lang_type) throwErrorMsg("语言类型code码:【{$val['$i18n_lang_type_guid']}】不存在");
            $i18n_lang_type_code = $i18n_lang_type->i18n_lang_type_code;

            $data[] = [
                $i18n_lang_type_code,
                $val['faq_questions'],
                $val['faq_answer'],
                $val['faq_sort'],
            ];
        }
        $excel = (new Excel())->exporTsheet($data);
        $excel->save('常见问题.xlsx');
    }


    /**
     * 导入excel
     * 
     * @param \app\common\arw\adjfut\src\UploadFile $file excel
     */
    public static function importExcel(\app\common\arw\adjfut\src\UploadFile $file): string
    {
        $msg = [];

        Db::startTrans();
        try {
            $excel = new Excel($file);
            $data = $excel->parseExcel(
                Tool::getExcelRule(self::EXCELFIELD),
                ['titleLine' => [1]]
            );
            if (!$data)  throwErrorMsg('excel无数据', 1);
            $msg = [];
            foreach ($data as $line => $value) {
                try {
                    $questions = $value['faq_questions'];
                    $model = self::importExcelInit($value);
                    $msg[] = "{$line} <span style='color:#27af49'>问题:【{$questions}】新增成功!</span><br>";
                } catch (\Throwable $th) {
                    $msg[] = "{$line} <span style='color:red'>{$th->getMessage()}</span><br>";
                }
            }
            Db::commit();
            return implode(', ', $msg);
        } catch (\Throwable $th) {
            Db::rollback();
            throw $th;
        }
    }


    /**
     * 导入excel初始化
     * 
     * @param array $value excel每行数据
     */
    public static function importExcelInit(array $value): void
    {
        $i18n_lang_type_code = $value['i18n_lang_type_code'];
        $faq_questions = $value['faq_questions'];
        $faq_answer = $value['faq_answer'];
        $faq_sort = $value['faq_sort'];


        // 语言类型code
        $i18n_lang_type = ModelI18nLangType::where('i18n_lang_type_code', $i18n_lang_type_code)->find();
        if (!$i18n_lang_type) throwErrorMsg("语言类型code码:【{$i18n_lang_type_code}】不存在");
        $i18n_lang_type_guid = $i18n_lang_type->i18n_lang_type_guid;

        self::create(
            [
                'i18n_lang_type_guid' => $i18n_lang_type_guid,
                'faq_questions' => $faq_questions,
                'faq_answer' => $faq_answer,
                'faq_sort' => $faq_sort,
            ],
            [
                'i18n_lang_type_guid',
                'faq_questions',
                'faq_answer',
                'faq_sort',
                'faq_guid',
                'faq_create_user_guid',
                'faq_update_user_guid'
            ]
        );
    }
}
